Changelog
=========


1.0.3 (2016-09-19)
------------------

- Add book use case
  [sverbois]

- Return unicode when loading templates
  [ebrehault]


1.0.2 (2016-04-09)
------------------

- Add rapidoLoad Javascript event
  [ebrehault]

- Allow to inject parent request path in Rapido path
  [ebrehault]

- Support TAL templates
  [ebrehault]

- Set content properly when calling block from content rule
  [ebrehault]

- External call to Rapido elements using @@rapido-call
  [ebrehault]

- API to access an external Rapido app
  [ebrehault] 


1.0.1 (2016-01-06)
------------------

- Ajax links
  [ebrehault]

- Better context.content computing and reinjection
  [ebrehault]


1.0 (2015-11-17)
----------------

- Initial release.
  [ebrehault]

